{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-tools/awscli:1.0"
                },
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envName": "AWS_CONFIG_FILE",
                            "envValue": "$(inputs.aws_config.path)"
                        },
                        {
                            "envName": "AWS_SHARED_CREDENTIALS_FILE",
                            "envValue": "$(inputs.aws_shared_credentials.path)"
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#awscli_download.cwl/aws_config"
                },
                {
                    "type": "File",
                    "id": "#awscli_download.cwl/aws_shared_credentials"
                },
                {
                    "type": "string",
                    "id": "#awscli_download.cwl/s3_endpoint"
                },
                {
                    "type": "string",
                    "id": "#awscli_download.cwl/s3_profile"
                },
                {
                    "type": "string",
                    "id": "#awscli_download.cwl/s3uri"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \\\"{\\\"real_time\\\": \\\"%E\\\", \\\"user_time\\\": %U, \\\"system_time\\\": %S, \\\"wall_clock\\\": %e, \\\"maximum_resident_set_size\\\": %M, \\\"average_total_mem\\\": %K, \\\"percent_of_cpu\\\": \\\"%P\\\"}\\\" -o $('aws_download.' + inputs.s3uri.split('/').slice(-1)[0] + '.time.json') aws --profile $(inputs.s3_profile) --endpoint-url $(inputs.s3_endpoint) --no-verify-ssl s3 cp $(inputs.s3uri) ."
                }
            ],
            "id": "#awscli_download.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.s3uri.split('/').slice(-1)[0])"
                    },
                    "id": "#awscli_download.cwl/output"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('aws_download.' + inputs.s3uri.split('/').slice(-1)[0] + '.time.json')"
                    },
                    "id": "#awscli_download.cwl/time_metrics"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/aws_config"
                },
                {
                    "type": "File",
                    "id": "#main/aws_shared_credentials"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/fastq_read1_uri"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/fastq_read2_uri"
                },
                {
                    "type": "string",
                    "id": "#main/s3_endpoint"
                },
                {
                    "type": "string",
                    "id": "#main/s3_profile"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/download_f1/output",
                    "id": "#main/downloaded_fastq_read1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/download_f2/output",
                    "id": "#main/downloaded_fastq_read2"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/download_f1/time_metrics",
                    "id": "#main/time_metrics_from_download_f1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/download_f2/time_metrics",
                    "id": "#main/time_metrics_from_download_f2"
                }
            ],
            "steps": [
                {
                    "run": "#awscli_download.cwl",
                    "scatter": [
                        "#main/download_f1/s3uri"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/aws_config",
                            "id": "#main/download_f1/aws_config"
                        },
                        {
                            "source": "#main/aws_shared_credentials",
                            "id": "#main/download_f1/aws_shared_credentials"
                        },
                        {
                            "source": "#main/s3_endpoint",
                            "id": "#main/download_f1/s3_endpoint"
                        },
                        {
                            "source": "#main/s3_profile",
                            "id": "#main/download_f1/s3_profile"
                        },
                        {
                            "source": "#main/fastq_read1_uri",
                            "id": "#main/download_f1/s3uri"
                        }
                    ],
                    "out": [
                        "#main/download_f1/output",
                        "#main/download_f1/time_metrics"
                    ],
                    "id": "#main/download_f1"
                },
                {
                    "run": "#awscli_download.cwl",
                    "scatter": [
                        "#main/download_f2/s3uri"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/aws_config",
                            "id": "#main/download_f2/aws_config"
                        },
                        {
                            "source": "#main/aws_shared_credentials",
                            "id": "#main/download_f2/aws_shared_credentials"
                        },
                        {
                            "source": "#main/s3_endpoint",
                            "id": "#main/download_f2/s3_endpoint"
                        },
                        {
                            "source": "#main/s3_profile",
                            "id": "#main/download_f2/s3_profile"
                        },
                        {
                            "source": "#main/fastq_read2_uri",
                            "id": "#main/download_f2/s3uri"
                        }
                    ],
                    "out": [
                        "#main/download_f2/output",
                        "#main/download_f2/time_metrics"
                    ],
                    "id": "#main/download_f2"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
